@@ -6,13 +6,15 @@ def test_suggest_new_X():
     from spotPython.fun.objectivefunctions import analytical
     from spotPython.spot.spot import Spot
     from spotPython.utils.repair import repair_non_numeric
+    from spotPython.utils.init import fun_control_init, optimizer_control_init, surrogate_control_init, design_control_init
     fun = analytical().fun_sphere
     nn = 3
     spot_test = Spot(
         fun=fun,
+        fun_control=fun_control_init(
         lower=np.array([-10,-1]),
         upper=np.array([10,1]),
-        n_points=nn
+        n_points=nn)
     )
     # (S-2) Initial Design:
     spot_test.X = spot_test.generate_design(size=spot_test.design_control["init_size"],
